﻿using UnityEngine;

public class CameraFollow : MonoBehaviour
{
	public float reachTime = 1.0f;
	public float margin = 3.0f;
	public float stopDistance = 1.0f;

	private Transform _tr;
	private Transform _playertr;
	private Camera _cam;
	private Vector3 _camVelocity;
	private bool m_Moving;

	void Start ()
	{
		var playerGO = GameObject.FindWithTag("Player");
		if (!playerGO)
		{
			Debug.LogError ("No Player object found", this);
			return;
		}
		_playertr = playerGO.transform;
		_tr = transform;
		_cam = GetComponent<Camera>();
	}
	
	void LateUpdate ()
	{
		if (!_playertr)
			return;

		var camsizeY = _cam.orthographicSize;
		var camsizeX = camsizeY * _cam.aspect;
		var campos = _tr.position;
		var campos0 = campos;
		var plpos = _playertr.position;
		campos0.z = plpos.z;

		// generate world tiles
		World.instance.EnsureHasTiles(
			(int)(campos0.x - camsizeX - 1),
			(int)(campos0.y - camsizeY - 1),
			(int)(campos0.x + camsizeX + 1),
			(int)(campos0.y + camsizeY + 1)
		);
		World.instance.EnsureHasTiles(
			(int)(plpos.x - 2),
			(int)(plpos.y - 2),
			(int)(plpos.x + 2),
			(int)(plpos.y + 2)
			);

		// if we got near edges of screen, start moving camera to player
		if (plpos.x < campos0.x - camsizeX + margin || plpos.x > campos0.x + camsizeX - margin ||
		    plpos.y < campos0.y - camsizeY + margin || plpos.y > campos0.y + camsizeY - margin)
		{
			m_Moving = true;
		}

		// if we got near the player, stop moving camera
		if (plpos.x >= campos0.x-stopDistance && plpos.y >= campos0.y-stopDistance &&
		    plpos.x <= campos0.x+stopDistance && plpos.y <= campos0.y+stopDistance)
		{
			m_Moving = false;
		}

		// move camera if needed
		if (m_Moving)
		{
			campos0 = Vector3.SmoothDamp(campos0, plpos, ref _camVelocity, reachTime);
			_tr.position = new Vector3(campos0.x, campos0.y, campos.z);
		}
	}
}
