﻿using UnityEngine;
using System.Collections;

public class Quest : MonoBehaviour
{
	public float distance = 5.0f;

	[Multiline]
	public string text;

	public Sprite heroSprite;

	public bool giveWeapon = false;
	public WeaponKind weapon;

	string title;
	public void SetTitle(string t) { title = t; }

	public void OnTriggerEnter2D(Collider2D other)
	{
		var player = PlayerController.instance;
		if (!player)
			return;
		if (player.transform != other.transform)
			return;	
		StartCoroutine(PlayerEnterQuest ());
	}

	IEnumerator PlayerEnterQuest()
	{
		// destroy collider
		Destroy (GetComponent<Collider2D>());

		var quests = Quests.instance;

		// sound
		AudioSource.PlayClipAtPoint(quests.questSound, transform.position);
		// score
		PlayerController.instance.AddScore(5);

		// pause game, enable UI
		Time.timeScale = 0.0f;
		quests.uiBackground.gameObject.SetActive(true);
		AudioListener.volume = 0.3f;

		// show quest text & hero
		quests.uiText.text = text;
		if (heroSprite)
		{
			quests.uiHero.enabled = true;
			quests.uiHero.sprite = heroSprite;
		}
		else
			quests.uiHero.enabled = false;

		// wait for button press
		quests.uiButton.onClick.RemoveAllListeners();
		bool okPressed = false;
		quests.uiButton.onClick.AddListener (() => okPressed = true);
		while (!okPressed)
		{
			yield return 0;
		}

		// disable UI and restore time scale
		quests.uiBackground.gameObject.SetActive(false);
		Time.timeScale = 1.0f;
		AudioListener.volume = 1.0f;

		// give weapon?
		if (giveWeapon)
		{
			WeaponSystem.instance.PickupWeapon(weapon, 10);
		}

		// destroy this quest
		Fader.StartFade (gameObject, 1.0f);

		// start next quest
		quests.NextQuest();
	}
}
