﻿using UnityEngine;
using System.Collections;

public enum WeaponKind
{
	Bass = 0,
	Count
}


public class WeaponSystem : MonoBehaviour
{
	static WeaponSystem s_Instance;
	public static WeaponSystem instance { get { return s_Instance; } }

	public GameObject[] m_Prefabs;
	public UnityEngine.UI.Image[] m_UIImages;
	public UnityEngine.UI.Text[] m_UITexts;


	int[] m_Ammo = new int[(int)WeaponKind.Count];
	WeaponKind m_ActiveWeapon;

	public bool HasAmmo(WeaponKind kind) { return m_Ammo[(int)kind] > 0; }

	void Awake()
	{
		if (s_Instance != null)
			Debug.LogError("WeaponSystem already exists!");
		s_Instance = this;
	}

	void Start()
	{
		for (int i = 0; i < (int)WeaponKind.Count; ++i)
			UpdateUI ((WeaponKind)i);
	}

	public void PickupWeapon(WeaponKind kind, int amount)
	{
		m_Ammo[(int)kind] += amount;
		UpdateUI (kind);
	}

	public bool FireActiveWeapon(Vector3 pos, Vector3 dir)
	{
		return FireWeapon(m_ActiveWeapon, pos, dir);
	}

	public bool FireWeapon(WeaponKind kind, Vector3 pos, Vector3 dir)
	{
		if (!HasAmmo(kind))
			return false;

		--m_Ammo[(int)kind];

		// instantiate prefab
		var go = GameObject.Instantiate(m_Prefabs[(int)kind], pos, Quaternion.identity) as GameObject;
		//@TODO: direction
		var rend = go.GetComponent<Renderer>();
		if (rend)
			rend.sortingLayerName = "Player";

		UpdateUI(kind);
		//@TODO switch to another weapon if ran out of ammo
		return true;
	}

	void UpdateUI(WeaponKind kind)
	{
		int idx = (int)kind;
		if (HasAmmo(kind))
		{
			m_UIImages[idx].color = Color.white;
			m_UITexts[idx].enabled = true;
			m_UITexts[idx].text = m_Ammo[idx].ToString();
		}
		else
		{
			m_UIImages[idx].color = new Color(0.5f,0.5f,0.5f,0.3f);
			m_UITexts[idx].enabled = false;
		}
	}
}
